@@ -1,6 +1,5 @@
 from hpogrid.components.grid_handler import GridHandler
 from hpogrid.components.job_builder import JobBuilder
-#from hpogrid.idds_interface.idds_handler import iDDSHandler
 from hpogrid.utils.grid_site_info import GridSiteInfo
 from hpogrid.idds_interface.steering import SteeringIDDS
 from hpogrid.configuration.configuration_base import ConfigurationBase
@@ -10,5 +9,5 @@ from hpogrid.configuration.search_space_configuration import SearchSpaceConfigur
 from hpogrid.configuration.project_configuration import ProjectConfiguration
 from hpogrid.configuration.model_configuration import ModelConfiguration
 from hpogrid.utils.helper import get_workdir, load_configuration
-
+from hpogrid.components.environment_settings import *
 from hpogrid.components.core import *
\ No newline at end of file
