@@ -17,8 +17,8 @@ kAlgoMap = {
     'bayesian': 'hyperopt'
 }
 
-
-
+kDefaultiDDSConfigPath = '/afs/cern.ch/work/c/chlcheng/public/hpogrid/idds.cfg'
+kDefaultProxyPath = '/etc/pki/tls/cert.pem'
 #####################################################
 ##############    Paths Related      ################
 #####################################################
@@ -61,7 +61,7 @@ kGPUSiteNGPU = {
 
 kDefaultContainer = '/cvmfs/unpacked.cern.ch/gitlab-registry.cern.ch/aml/hyperparameter-optimization/alkaid-qt/hpogrid:latest'
 kDefaultContainer2 = '/cvmfs/unpacked.cern.ch/gitlab-registry.cern.ch/clcheng/hyperparameter-optimization-on-the-grid:latest'
-kDefaultContainer3 = 'docker://gitlab-registry.cern.ch/aml/hyperparameter-optimization/alkaid-qt/hpogrid:latest'
+kDefaultiDDSContainer = 'gitlab-registry.cern.ch/aml/hyperparameter-optimization/alkaid-qt/hpogrid:latest'
 kDefaultContainer4 = 'docker://gitlab-registry.cern.ch/aml/hyperparameter-optimization/alkaid-qt/hpogrid:base'
 
 kSearchAlgorithms = ['hyperopt', 'skopt', 'bohb', 'ax', 'tune', 'random', 'grid', 'bayesian', 'nevergrad']
