@@ -312,7 +312,7 @@ class JobBuilder():
         try:
             extracted_files = []
             if environment_settings.is_grid_job():
-                datadir = nvironment_settings.get_datadir()
+                datadir = environment_settings.get_datadir()
                 extracted_files = helper.extract_tarball(datadir, datadir)
                 
             ray.init(include_dashboard=False,
