@@ -3,17 +3,16 @@ import argparse
 import json
 
 from hpogrid.components.defaults import *
-from hpogrid.configuration.configuration_base import ConfigurationBase, kConfigAction
-from hpogrid.utils import stylus
+from hpogrid import ConfigurationBase
 
 class ModelConfiguration(ConfigurationBase):
 
-    def initialize(self):
-        self.description = 'Manage configuration for machine learning model'
-        self.usage = 'hpogrid model_config <action> <config_name> [<options>]'
-        self.config_type = 'model'
-        self.list_columns = ['Model Configuration']
-        self.show_columns = ['Attribute', 'Value']  
+    config_type = 'model'
+    description = 'Manage configuration for machine learning model'
+    usage = 'hpogrid model_config <action> <config_name> [<options>]'
+    list_columns = ['Model Configuration']
+    show_columns = ['Attribute', 'Value']  
+    json_interpreted = ['param']
 
     def get_parser(self, action=None):
         parser = self.get_base_parser()              
@@ -30,15 +29,3 @@ class ModelConfiguration(ConfigurationBase):
         else:
             parser = super().get_parser(action)
         return parser
-
-    def process_config(self, config):
-        super().process_config(config)
-
-        if ('param' in config) and isinstance(config['param'],str):
-            try:
-                config['param'] = json.loads(config['param'])
-            except JSONDecodeError:
-                print('ERROR: Cannot decode input param into json format. Please check your input.')
-                return None
-
-        return config 
