@@ -34,8 +34,8 @@ def transpose_config(config):
     # format idds configuration
     idds_config = {}
     idds_config['steeringExec'] = ("run --rm -v \"$(pwd)\":{idds_base_path} {container} " +\
-    "/bin/bash -c \"{cmd}\" ").format(idds_base_path=kiDDSBasePath, container=kDefaultContainer, cmd=generator_cmd)
-    idds_config['evaluationExec'] = "\"pip install --upgrade hpogrid & " + \
+    "/bin/bash -c \"{cmd}\" ").format(idds_base_path=kiDDSBasePath, container=kDefaultiDDSContainer, cmd=generator_cmd)
+    idds_config['evaluationExec'] = "\"pip install --upgrade hpogrid && " + \
                                     "hpogrid run {project_name} --mode idds\"".format(project_name=project_name)
     idds_config['evaluationContainer'] = evaluation_container
     idds_config['evaluationInput'] = kiDDSHPinput
@@ -85,7 +85,21 @@ def save_idds_output_from_metadata(metadata):
         
         
         
-        
-        
+def check_log(workload_id:int, request_id=None,
+              idds_config_path=kDefaultiDDSConfigPath,
+              proxy_path=kDefaultProxyPath):
+    os.environ['IDDS_CONFIG'] = idds_config_path
+    original_proxy = os.environ.get('X509_USER_PROXY', None)
+    os.environ['X509_USER_PROXY'] = proxy_path
+    from idds.client.client import Client
+    from idds.common.utils import get_rest_host
+    host = get_rest_host()
+    client = Client(host=host)
+    print('INFO: Fetching iDDS log files for tht task: {}'.format(workload_id))
+    filename = client.download_logs(workload_id=workload_id, request_id=request_id, dest_dir='/tmp')
+    print('INFO: iDDS log files can be found at:')
+    print(filename)
+    if original_proxy:
+        os.environ['X509_USER_PROXY'] = original_proxy
         
         
\ No newline at end of file
